execution

package
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 12, 2026 License: Apache-2.0 Imports: 8 Imported by: 0

Documentation

Overview

Package execution is a generated GoMock package.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Assigner

type Assigner interface {
	// Assign assigns a value to a given expression. e.g .name = "updated"
	Assign(ctx context.Context, expression string, value any) error
	// AssignZip assigns an array of values to a given array expression using zip operation. e.g .items[] = ["a", "b", "c"]
	// The length of the values array must match the length of the array expression.
	AssignZip(ctx context.Context, expression string, values []any) error
}

type Evaluator

type Evaluator interface {
	// Evaluate evaluates a JQ expression and returns the results.
	Evaluate(ctx context.Context, expression string) ([]any, error)
	// GetObject returns the object as a golang basic type.
	GetObject() (any, error)
}

type JQCompileError

type JQCompileError struct {
	Expression string
	Err        error
}

func (*JQCompileError) Error

func (e *JQCompileError) Error() string

func (*JQCompileError) Unwrap

func (e *JQCompileError) Unwrap() error

type JQExecutionError

type JQExecutionError struct {
	Expression string
	Err        error
}

func (*JQExecutionError) Error

func (e *JQExecutionError) Error() string

func (*JQExecutionError) Unwrap

func (e *JQExecutionError) Unwrap() error

type JQParseError

type JQParseError struct {
	Expression string
	Err        error
}

func (*JQParseError) Error

func (e *JQParseError) Error() string

func (*JQParseError) Unwrap

func (e *JQParseError) Unwrap() error

type MockAssigner

type MockAssigner struct {
	// contains filtered or unexported fields
}

MockAssigner is a mock of Assigner interface.

func NewMockAssigner

func NewMockAssigner(ctrl *gomock.Controller) *MockAssigner

NewMockAssigner creates a new mock instance.

func (*MockAssigner) Assign

func (m *MockAssigner) Assign(ctx context.Context, expression string, value any) error

Assign mocks base method.

func (*MockAssigner) AssignZip

func (m *MockAssigner) AssignZip(ctx context.Context, expression string, values []any) error

AssignZip mocks base method.

func (*MockAssigner) EXPECT

EXPECT returns an object that allows the caller to indicate expected use.

type MockAssignerMockRecorder

type MockAssignerMockRecorder struct {
	// contains filtered or unexported fields
}

MockAssignerMockRecorder is the mock recorder for MockAssigner.

func (*MockAssignerMockRecorder) Assign

func (mr *MockAssignerMockRecorder) Assign(ctx, expression, value any) *gomock.Call

Assign indicates an expected call of Assign.

func (*MockAssignerMockRecorder) AssignZip

func (mr *MockAssignerMockRecorder) AssignZip(ctx, expression, values any) *gomock.Call

AssignZip indicates an expected call of AssignZip.

type MockEvaluator

type MockEvaluator struct {
	// contains filtered or unexported fields
}

MockEvaluator is a mock of Evaluator interface.

func NewMockEvaluator

func NewMockEvaluator(ctrl *gomock.Controller) *MockEvaluator

NewMockEvaluator creates a new mock instance.

func (*MockEvaluator) EXPECT

EXPECT returns an object that allows the caller to indicate expected use.

func (*MockEvaluator) Evaluate

func (m *MockEvaluator) Evaluate(ctx context.Context, expression string) ([]any, error)

Evaluate mocks base method.

func (*MockEvaluator) GetObject

func (m *MockEvaluator) GetObject() (any, error)

GetObject mocks base method.

type MockEvaluatorMockRecorder

type MockEvaluatorMockRecorder struct {
	// contains filtered or unexported fields
}

MockEvaluatorMockRecorder is the mock recorder for MockEvaluator.

func (*MockEvaluatorMockRecorder) Evaluate

func (mr *MockEvaluatorMockRecorder) Evaluate(ctx, expression any) *gomock.Call

Evaluate indicates an expected call of Evaluate.

func (*MockEvaluatorMockRecorder) GetObject

func (mr *MockEvaluatorMockRecorder) GetObject() *gomock.Call

GetObject indicates an expected call of GetObject.

type MockRunner

type MockRunner struct {
	// contains filtered or unexported fields
}

MockRunner is a mock of Runner interface.

func NewMockRunner

func NewMockRunner(ctrl *gomock.Controller) *MockRunner

NewMockRunner creates a new mock instance.

func (*MockRunner) Assign

func (m *MockRunner) Assign(ctx context.Context, expression string, value any) error

Assign mocks base method.

func (*MockRunner) AssignZip

func (m *MockRunner) AssignZip(ctx context.Context, expression string, values []any) error

AssignZip mocks base method.

func (*MockRunner) EXPECT

func (m *MockRunner) EXPECT() *MockRunnerMockRecorder

EXPECT returns an object that allows the caller to indicate expected use.

func (*MockRunner) Evaluate

func (m *MockRunner) Evaluate(ctx context.Context, expression string) ([]any, error)

Evaluate mocks base method.

func (*MockRunner) GetObject

func (m *MockRunner) GetObject() (any, error)

GetObject mocks base method.

type MockRunnerMockRecorder

type MockRunnerMockRecorder struct {
	// contains filtered or unexported fields
}

MockRunnerMockRecorder is the mock recorder for MockRunner.

func (*MockRunnerMockRecorder) Assign

func (mr *MockRunnerMockRecorder) Assign(ctx, expression, value any) *gomock.Call

Assign indicates an expected call of Assign.

func (*MockRunnerMockRecorder) AssignZip

func (mr *MockRunnerMockRecorder) AssignZip(ctx, expression, values any) *gomock.Call

AssignZip indicates an expected call of AssignZip.

func (*MockRunnerMockRecorder) Evaluate

func (mr *MockRunnerMockRecorder) Evaluate(ctx, expression any) *gomock.Call

Evaluate indicates an expected call of Evaluate.

func (*MockRunnerMockRecorder) GetObject

func (mr *MockRunnerMockRecorder) GetObject() *gomock.Call

GetObject indicates an expected call of GetObject.

type Runner

type Runner interface {
	Evaluator
	Assigner
}

func NewDefaultRunner

func NewDefaultRunner(source any) Runner

func NewRunner

func NewRunner(source any, queryMaxResults *int, queryTimeoutInMilliseconds *int) Runner

Jump to