Documentation
¶
Overview ¶
Package execution is a generated GoMock package.
Index ¶
- type Assigner
- type Evaluator
- type JQCompileError
- type JQExecutionError
- type JQParseError
- type MockAssigner
- type MockAssignerMockRecorder
- type MockEvaluator
- type MockEvaluatorMockRecorder
- type MockRunner
- func (m *MockRunner) Assign(ctx context.Context, expression string, value any) error
- func (m *MockRunner) AssignZip(ctx context.Context, expression string, values []any) error
- func (m *MockRunner) EXPECT() *MockRunnerMockRecorder
- func (m *MockRunner) Evaluate(ctx context.Context, expression string) ([]any, error)
- func (m *MockRunner) GetObject() (any, error)
- type MockRunnerMockRecorder
- func (mr *MockRunnerMockRecorder) Assign(ctx, expression, value any) *gomock.Call
- func (mr *MockRunnerMockRecorder) AssignZip(ctx, expression, values any) *gomock.Call
- func (mr *MockRunnerMockRecorder) Evaluate(ctx, expression any) *gomock.Call
- func (mr *MockRunnerMockRecorder) GetObject() *gomock.Call
- type Runner
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Assigner ¶
type Assigner interface {
// Assign assigns a value to a given expression. e.g .name = "updated"
Assign(ctx context.Context, expression string, value any) error
// AssignZip assigns an array of values to a given array expression using zip operation. e.g .items[] = ["a", "b", "c"]
// The length of the values array must match the length of the array expression.
AssignZip(ctx context.Context, expression string, values []any) error
}
type JQCompileError ¶
func (*JQCompileError) Error ¶
func (e *JQCompileError) Error() string
func (*JQCompileError) Unwrap ¶
func (e *JQCompileError) Unwrap() error
type JQExecutionError ¶
func (*JQExecutionError) Error ¶
func (e *JQExecutionError) Error() string
func (*JQExecutionError) Unwrap ¶
func (e *JQExecutionError) Unwrap() error
type JQParseError ¶
func (*JQParseError) Error ¶
func (e *JQParseError) Error() string
func (*JQParseError) Unwrap ¶
func (e *JQParseError) Unwrap() error
type MockAssigner ¶
type MockAssigner struct {
// contains filtered or unexported fields
}
MockAssigner is a mock of Assigner interface.
func NewMockAssigner ¶
func NewMockAssigner(ctrl *gomock.Controller) *MockAssigner
NewMockAssigner creates a new mock instance.
func (*MockAssigner) EXPECT ¶
func (m *MockAssigner) EXPECT() *MockAssignerMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
type MockAssignerMockRecorder ¶
type MockAssignerMockRecorder struct {
// contains filtered or unexported fields
}
MockAssignerMockRecorder is the mock recorder for MockAssigner.
type MockEvaluator ¶
type MockEvaluator struct {
// contains filtered or unexported fields
}
MockEvaluator is a mock of Evaluator interface.
func NewMockEvaluator ¶
func NewMockEvaluator(ctrl *gomock.Controller) *MockEvaluator
NewMockEvaluator creates a new mock instance.
func (*MockEvaluator) EXPECT ¶
func (m *MockEvaluator) EXPECT() *MockEvaluatorMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
func (*MockEvaluator) GetObject ¶
func (m *MockEvaluator) GetObject() (any, error)
GetObject mocks base method.
type MockEvaluatorMockRecorder ¶
type MockEvaluatorMockRecorder struct {
// contains filtered or unexported fields
}
MockEvaluatorMockRecorder is the mock recorder for MockEvaluator.
func (*MockEvaluatorMockRecorder) Evaluate ¶
func (mr *MockEvaluatorMockRecorder) Evaluate(ctx, expression any) *gomock.Call
Evaluate indicates an expected call of Evaluate.
func (*MockEvaluatorMockRecorder) GetObject ¶
func (mr *MockEvaluatorMockRecorder) GetObject() *gomock.Call
GetObject indicates an expected call of GetObject.
type MockRunner ¶
type MockRunner struct {
// contains filtered or unexported fields
}
MockRunner is a mock of Runner interface.
func NewMockRunner ¶
func NewMockRunner(ctrl *gomock.Controller) *MockRunner
NewMockRunner creates a new mock instance.
func (*MockRunner) EXPECT ¶
func (m *MockRunner) EXPECT() *MockRunnerMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
func (*MockRunner) GetObject ¶
func (m *MockRunner) GetObject() (any, error)
GetObject mocks base method.
type MockRunnerMockRecorder ¶
type MockRunnerMockRecorder struct {
// contains filtered or unexported fields
}
MockRunnerMockRecorder is the mock recorder for MockRunner.
func (*MockRunnerMockRecorder) Assign ¶
func (mr *MockRunnerMockRecorder) Assign(ctx, expression, value any) *gomock.Call
Assign indicates an expected call of Assign.
func (*MockRunnerMockRecorder) AssignZip ¶
func (mr *MockRunnerMockRecorder) AssignZip(ctx, expression, values any) *gomock.Call
AssignZip indicates an expected call of AssignZip.
func (*MockRunnerMockRecorder) Evaluate ¶
func (mr *MockRunnerMockRecorder) Evaluate(ctx, expression any) *gomock.Call
Evaluate indicates an expected call of Evaluate.
func (*MockRunnerMockRecorder) GetObject ¶
func (mr *MockRunnerMockRecorder) GetObject() *gomock.Call
GetObject indicates an expected call of GetObject.